# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetRadiusProfileResult',
    'AwaitableGetRadiusProfileResult',
    'get_radius_profile',
    'get_radius_profile_output',
]

@pulumi.output_type
class GetRadiusProfileResult:
    """
    A collection of values returned by getRadiusProfile.
    """
    def __init__(__self__, id=None, name=None, site=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if site and not isinstance(site, str):
            raise TypeError("Expected argument 'site' to be a str")
        pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this AP group.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the RADIUS profile to look up. Defaults to `Default`.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def site(self) -> _builtins.str:
        """
        The name of the site the RADIUS profile is associated with.
        """
        return pulumi.get(self, "site")


class AwaitableGetRadiusProfileResult(GetRadiusProfileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRadiusProfileResult(
            id=self.id,
            name=self.name,
            site=self.site)


def get_radius_profile(name: Optional[_builtins.str] = None,
                       site: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRadiusProfileResult:
    """
    `RadiusProfile` data source can be used to retrieve the ID for a RADIUS profile by name.


    :param _builtins.str name: The name of the RADIUS profile to look up. Defaults to `Default`.
    :param _builtins.str site: The name of the site the RADIUS profile is associated with.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['site'] = site
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('unifi:index/getRadiusProfile:getRadiusProfile', __args__, opts=opts, typ=GetRadiusProfileResult).value

    return AwaitableGetRadiusProfileResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        site=pulumi.get(__ret__, 'site'))
def get_radius_profile_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              site: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRadiusProfileResult]:
    """
    `RadiusProfile` data source can be used to retrieve the ID for a RADIUS profile by name.


    :param _builtins.str name: The name of the RADIUS profile to look up. Defaults to `Default`.
    :param _builtins.str site: The name of the site the RADIUS profile is associated with.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['site'] = site
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('unifi:index/getRadiusProfile:getRadiusProfile', __args__, opts=opts, typ=GetRadiusProfileResult)
    return __ret__.apply(lambda __response__: GetRadiusProfileResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        site=pulumi.get(__response__, 'site')))
