# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetRecordsResultResult',
]

@pulumi.output_type
class GetRecordsResultResult(dict):
    def __init__(__self__, *,
                 enabled: _builtins.bool,
                 id: _builtins.str,
                 name: _builtins.str,
                 port: _builtins.int,
                 priority: _builtins.int,
                 record: _builtins.str,
                 site: _builtins.str,
                 ttl: _builtins.int,
                 type: _builtins.str,
                 weight: _builtins.int):
        """
        :param _builtins.bool enabled: Whether the DNS record is enabled.
        :param _builtins.str id: The unique identifier of this resource.
        :param _builtins.str name: DNS record name.
        :param _builtins.int port: The port of the DNS record.
        :param _builtins.int priority: Priority of the DNS records. Present only for MX and SRV records; unused by other record types.
        :param _builtins.str record: DNS record content.
        :param _builtins.str site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param _builtins.int ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 0 means 'automatic'.
        :param _builtins.str type: The type of the DNS record.
        :param _builtins.int weight: A numeric value indicating the relative weight of the record.
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "record", record)
        pulumi.set(__self__, "site", site)
        pulumi.set(__self__, "ttl", ttl)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "weight", weight)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Whether the DNS record is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        DNS record name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        The port of the DNS record.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> _builtins.int:
        """
        Priority of the DNS records. Present only for MX and SRV records; unused by other record types.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter
    def record(self) -> _builtins.str:
        """
        DNS record content.
        """
        return pulumi.get(self, "record")

    @_builtins.property
    @pulumi.getter
    def site(self) -> _builtins.str:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> _builtins.int:
        """
        Time To Live (TTL) of the DNS record in seconds. Setting to 0 means 'automatic'.
        """
        return pulumi.get(self, "ttl")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of the DNS record.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def weight(self) -> _builtins.int:
        """
        A numeric value indicating the relative weight of the record.
        """
        return pulumi.get(self, "weight")


