# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RadiusProfileArgs', 'RadiusProfile']

@pulumi.input_type
class RadiusProfileArgs:
    def __init__(__self__, *,
                 accounting_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 acct_servers: Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAcctServerArgs']]]] = None,
                 auth_servers: Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAuthServerArgs']]]] = None,
                 interim_update_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 interim_update_interval: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 use_usg_acct_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_usg_auth_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 vlan_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 vlan_wlan_mode: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RadiusProfile resource.
        :param pulumi.Input[_builtins.bool] accounting_enabled: Enable RADIUS accounting to track user sessions, including login/logout times and data usage. Useful for billing and audit purposes.
        :param pulumi.Input[Sequence[pulumi.Input['RadiusProfileAcctServerArgs']]] acct_servers: List of RADIUS accounting servers to use with this profile. Accounting servers track session data like connection time and data usage. Each server requires:
                 * IP address of the RADIUS server
                 * Port number (default: 1813)
                 * Shared secret for secure communication
        :param pulumi.Input[Sequence[pulumi.Input['RadiusProfileAuthServerArgs']]] auth_servers: List of RADIUS authentication servers to use with this profile. Multiple servers provide failover - if the first server is unreachable, the system will try the next server in the list. Each server requires:
                 * IP address of the RADIUS server
                 * Shared secret for secure communication
        :param pulumi.Input[_builtins.bool] interim_update_enabled: Enable periodic updates during active sessions. This allows tracking of ongoing session data like bandwidth usage.
        :param pulumi.Input[_builtins.int] interim_update_interval: The interval (in seconds) between interim updates when `interim_update_enabled` is true. Default is 3600 seconds (1 hour).
        :param pulumi.Input[_builtins.str] name: A friendly name for the RADIUS profile to help identify its purpose (e.g., 'Corporate Users' or 'Guest Access').
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the RADIUS profile should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] use_usg_acct_server: Use the controller as a RADIUS accounting server. This allows local accounting without an external RADIUS server.
        :param pulumi.Input[_builtins.bool] use_usg_auth_server: Use the controller as a RADIUS authentication server. This allows local authentication without an external RADIUS server.
        :param pulumi.Input[_builtins.bool] vlan_enabled: Enable VLAN assignment for wired clients based on RADIUS attributes. This allows network segmentation based on user authentication.
        :param pulumi.Input[_builtins.str] vlan_wlan_mode: VLAN assignment mode for wireless networks. Valid values are:
                 * `disabled` - Do not use RADIUS-assigned VLANs
                 * `optional` - Use RADIUS-assigned VLAN if provided
                 * `required` - Require RADIUS-assigned VLAN for authentication to succeed
        """
        if accounting_enabled is not None:
            pulumi.set(__self__, "accounting_enabled", accounting_enabled)
        if acct_servers is not None:
            pulumi.set(__self__, "acct_servers", acct_servers)
        if auth_servers is not None:
            pulumi.set(__self__, "auth_servers", auth_servers)
        if interim_update_enabled is not None:
            pulumi.set(__self__, "interim_update_enabled", interim_update_enabled)
        if interim_update_interval is not None:
            pulumi.set(__self__, "interim_update_interval", interim_update_interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if use_usg_acct_server is not None:
            pulumi.set(__self__, "use_usg_acct_server", use_usg_acct_server)
        if use_usg_auth_server is not None:
            pulumi.set(__self__, "use_usg_auth_server", use_usg_auth_server)
        if vlan_enabled is not None:
            pulumi.set(__self__, "vlan_enabled", vlan_enabled)
        if vlan_wlan_mode is not None:
            pulumi.set(__self__, "vlan_wlan_mode", vlan_wlan_mode)

    @_builtins.property
    @pulumi.getter(name="accountingEnabled")
    def accounting_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable RADIUS accounting to track user sessions, including login/logout times and data usage. Useful for billing and audit purposes.
        """
        return pulumi.get(self, "accounting_enabled")

    @accounting_enabled.setter
    def accounting_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "accounting_enabled", value)

    @_builtins.property
    @pulumi.getter(name="acctServers")
    def acct_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAcctServerArgs']]]]:
        """
        List of RADIUS accounting servers to use with this profile. Accounting servers track session data like connection time and data usage. Each server requires:
          * IP address of the RADIUS server
          * Port number (default: 1813)
          * Shared secret for secure communication
        """
        return pulumi.get(self, "acct_servers")

    @acct_servers.setter
    def acct_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAcctServerArgs']]]]):
        pulumi.set(self, "acct_servers", value)

    @_builtins.property
    @pulumi.getter(name="authServers")
    def auth_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAuthServerArgs']]]]:
        """
        List of RADIUS authentication servers to use with this profile. Multiple servers provide failover - if the first server is unreachable, the system will try the next server in the list. Each server requires:
          * IP address of the RADIUS server
          * Shared secret for secure communication
        """
        return pulumi.get(self, "auth_servers")

    @auth_servers.setter
    def auth_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAuthServerArgs']]]]):
        pulumi.set(self, "auth_servers", value)

    @_builtins.property
    @pulumi.getter(name="interimUpdateEnabled")
    def interim_update_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable periodic updates during active sessions. This allows tracking of ongoing session data like bandwidth usage.
        """
        return pulumi.get(self, "interim_update_enabled")

    @interim_update_enabled.setter
    def interim_update_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "interim_update_enabled", value)

    @_builtins.property
    @pulumi.getter(name="interimUpdateInterval")
    def interim_update_interval(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The interval (in seconds) between interim updates when `interim_update_enabled` is true. Default is 3600 seconds (1 hour).
        """
        return pulumi.get(self, "interim_update_interval")

    @interim_update_interval.setter
    def interim_update_interval(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "interim_update_interval", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the RADIUS profile to help identify its purpose (e.g., 'Corporate Users' or 'Guest Access').
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the RADIUS profile should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter(name="useUsgAcctServer")
    def use_usg_acct_server(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the controller as a RADIUS accounting server. This allows local accounting without an external RADIUS server.
        """
        return pulumi.get(self, "use_usg_acct_server")

    @use_usg_acct_server.setter
    def use_usg_acct_server(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_usg_acct_server", value)

    @_builtins.property
    @pulumi.getter(name="useUsgAuthServer")
    def use_usg_auth_server(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the controller as a RADIUS authentication server. This allows local authentication without an external RADIUS server.
        """
        return pulumi.get(self, "use_usg_auth_server")

    @use_usg_auth_server.setter
    def use_usg_auth_server(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_usg_auth_server", value)

    @_builtins.property
    @pulumi.getter(name="vlanEnabled")
    def vlan_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable VLAN assignment for wired clients based on RADIUS attributes. This allows network segmentation based on user authentication.
        """
        return pulumi.get(self, "vlan_enabled")

    @vlan_enabled.setter
    def vlan_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "vlan_enabled", value)

    @_builtins.property
    @pulumi.getter(name="vlanWlanMode")
    def vlan_wlan_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        VLAN assignment mode for wireless networks. Valid values are:
          * `disabled` - Do not use RADIUS-assigned VLANs
          * `optional` - Use RADIUS-assigned VLAN if provided
          * `required` - Require RADIUS-assigned VLAN for authentication to succeed
        """
        return pulumi.get(self, "vlan_wlan_mode")

    @vlan_wlan_mode.setter
    def vlan_wlan_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vlan_wlan_mode", value)


@pulumi.input_type
class _RadiusProfileState:
    def __init__(__self__, *,
                 accounting_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 acct_servers: Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAcctServerArgs']]]] = None,
                 auth_servers: Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAuthServerArgs']]]] = None,
                 interim_update_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 interim_update_interval: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 use_usg_acct_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_usg_auth_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 vlan_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 vlan_wlan_mode: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RadiusProfile resources.
        :param pulumi.Input[_builtins.bool] accounting_enabled: Enable RADIUS accounting to track user sessions, including login/logout times and data usage. Useful for billing and audit purposes.
        :param pulumi.Input[Sequence[pulumi.Input['RadiusProfileAcctServerArgs']]] acct_servers: List of RADIUS accounting servers to use with this profile. Accounting servers track session data like connection time and data usage. Each server requires:
                 * IP address of the RADIUS server
                 * Port number (default: 1813)
                 * Shared secret for secure communication
        :param pulumi.Input[Sequence[pulumi.Input['RadiusProfileAuthServerArgs']]] auth_servers: List of RADIUS authentication servers to use with this profile. Multiple servers provide failover - if the first server is unreachable, the system will try the next server in the list. Each server requires:
                 * IP address of the RADIUS server
                 * Shared secret for secure communication
        :param pulumi.Input[_builtins.bool] interim_update_enabled: Enable periodic updates during active sessions. This allows tracking of ongoing session data like bandwidth usage.
        :param pulumi.Input[_builtins.int] interim_update_interval: The interval (in seconds) between interim updates when `interim_update_enabled` is true. Default is 3600 seconds (1 hour).
        :param pulumi.Input[_builtins.str] name: A friendly name for the RADIUS profile to help identify its purpose (e.g., 'Corporate Users' or 'Guest Access').
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the RADIUS profile should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] use_usg_acct_server: Use the controller as a RADIUS accounting server. This allows local accounting without an external RADIUS server.
        :param pulumi.Input[_builtins.bool] use_usg_auth_server: Use the controller as a RADIUS authentication server. This allows local authentication without an external RADIUS server.
        :param pulumi.Input[_builtins.bool] vlan_enabled: Enable VLAN assignment for wired clients based on RADIUS attributes. This allows network segmentation based on user authentication.
        :param pulumi.Input[_builtins.str] vlan_wlan_mode: VLAN assignment mode for wireless networks. Valid values are:
                 * `disabled` - Do not use RADIUS-assigned VLANs
                 * `optional` - Use RADIUS-assigned VLAN if provided
                 * `required` - Require RADIUS-assigned VLAN for authentication to succeed
        """
        if accounting_enabled is not None:
            pulumi.set(__self__, "accounting_enabled", accounting_enabled)
        if acct_servers is not None:
            pulumi.set(__self__, "acct_servers", acct_servers)
        if auth_servers is not None:
            pulumi.set(__self__, "auth_servers", auth_servers)
        if interim_update_enabled is not None:
            pulumi.set(__self__, "interim_update_enabled", interim_update_enabled)
        if interim_update_interval is not None:
            pulumi.set(__self__, "interim_update_interval", interim_update_interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if use_usg_acct_server is not None:
            pulumi.set(__self__, "use_usg_acct_server", use_usg_acct_server)
        if use_usg_auth_server is not None:
            pulumi.set(__self__, "use_usg_auth_server", use_usg_auth_server)
        if vlan_enabled is not None:
            pulumi.set(__self__, "vlan_enabled", vlan_enabled)
        if vlan_wlan_mode is not None:
            pulumi.set(__self__, "vlan_wlan_mode", vlan_wlan_mode)

    @_builtins.property
    @pulumi.getter(name="accountingEnabled")
    def accounting_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable RADIUS accounting to track user sessions, including login/logout times and data usage. Useful for billing and audit purposes.
        """
        return pulumi.get(self, "accounting_enabled")

    @accounting_enabled.setter
    def accounting_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "accounting_enabled", value)

    @_builtins.property
    @pulumi.getter(name="acctServers")
    def acct_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAcctServerArgs']]]]:
        """
        List of RADIUS accounting servers to use with this profile. Accounting servers track session data like connection time and data usage. Each server requires:
          * IP address of the RADIUS server
          * Port number (default: 1813)
          * Shared secret for secure communication
        """
        return pulumi.get(self, "acct_servers")

    @acct_servers.setter
    def acct_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAcctServerArgs']]]]):
        pulumi.set(self, "acct_servers", value)

    @_builtins.property
    @pulumi.getter(name="authServers")
    def auth_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAuthServerArgs']]]]:
        """
        List of RADIUS authentication servers to use with this profile. Multiple servers provide failover - if the first server is unreachable, the system will try the next server in the list. Each server requires:
          * IP address of the RADIUS server
          * Shared secret for secure communication
        """
        return pulumi.get(self, "auth_servers")

    @auth_servers.setter
    def auth_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RadiusProfileAuthServerArgs']]]]):
        pulumi.set(self, "auth_servers", value)

    @_builtins.property
    @pulumi.getter(name="interimUpdateEnabled")
    def interim_update_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable periodic updates during active sessions. This allows tracking of ongoing session data like bandwidth usage.
        """
        return pulumi.get(self, "interim_update_enabled")

    @interim_update_enabled.setter
    def interim_update_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "interim_update_enabled", value)

    @_builtins.property
    @pulumi.getter(name="interimUpdateInterval")
    def interim_update_interval(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The interval (in seconds) between interim updates when `interim_update_enabled` is true. Default is 3600 seconds (1 hour).
        """
        return pulumi.get(self, "interim_update_interval")

    @interim_update_interval.setter
    def interim_update_interval(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "interim_update_interval", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the RADIUS profile to help identify its purpose (e.g., 'Corporate Users' or 'Guest Access').
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the RADIUS profile should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter(name="useUsgAcctServer")
    def use_usg_acct_server(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the controller as a RADIUS accounting server. This allows local accounting without an external RADIUS server.
        """
        return pulumi.get(self, "use_usg_acct_server")

    @use_usg_acct_server.setter
    def use_usg_acct_server(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_usg_acct_server", value)

    @_builtins.property
    @pulumi.getter(name="useUsgAuthServer")
    def use_usg_auth_server(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the controller as a RADIUS authentication server. This allows local authentication without an external RADIUS server.
        """
        return pulumi.get(self, "use_usg_auth_server")

    @use_usg_auth_server.setter
    def use_usg_auth_server(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_usg_auth_server", value)

    @_builtins.property
    @pulumi.getter(name="vlanEnabled")
    def vlan_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable VLAN assignment for wired clients based on RADIUS attributes. This allows network segmentation based on user authentication.
        """
        return pulumi.get(self, "vlan_enabled")

    @vlan_enabled.setter
    def vlan_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "vlan_enabled", value)

    @_builtins.property
    @pulumi.getter(name="vlanWlanMode")
    def vlan_wlan_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        VLAN assignment mode for wireless networks. Valid values are:
          * `disabled` - Do not use RADIUS-assigned VLANs
          * `optional` - Use RADIUS-assigned VLAN if provided
          * `required` - Require RADIUS-assigned VLAN for authentication to succeed
        """
        return pulumi.get(self, "vlan_wlan_mode")

    @vlan_wlan_mode.setter
    def vlan_wlan_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vlan_wlan_mode", value)


@pulumi.type_token("unifi:index/radiusProfile:RadiusProfile")
class RadiusProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accounting_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 acct_servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAcctServerArgs', 'RadiusProfileAcctServerArgsDict']]]]] = None,
                 auth_servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAuthServerArgs', 'RadiusProfileAuthServerArgsDict']]]]] = None,
                 interim_update_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 interim_update_interval: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 use_usg_acct_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_usg_auth_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 vlan_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 vlan_wlan_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `RadiusProfile` resource manages RADIUS authentication profiles for UniFi networks.

        RADIUS (Remote Authentication Dial-In User Service) profiles enable enterprise-grade authentication and authorization for:
          * 802.1X network access control
          * WPA2/WPA3-Enterprise wireless networks
          * Dynamic VLAN assignment
          * User activity accounting

        Each profile can be configured with:
          * Multiple authentication and accounting servers
          * VLAN assignment settings
          * Accounting update intervals

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] accounting_enabled: Enable RADIUS accounting to track user sessions, including login/logout times and data usage. Useful for billing and audit purposes.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAcctServerArgs', 'RadiusProfileAcctServerArgsDict']]]] acct_servers: List of RADIUS accounting servers to use with this profile. Accounting servers track session data like connection time and data usage. Each server requires:
                 * IP address of the RADIUS server
                 * Port number (default: 1813)
                 * Shared secret for secure communication
        :param pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAuthServerArgs', 'RadiusProfileAuthServerArgsDict']]]] auth_servers: List of RADIUS authentication servers to use with this profile. Multiple servers provide failover - if the first server is unreachable, the system will try the next server in the list. Each server requires:
                 * IP address of the RADIUS server
                 * Shared secret for secure communication
        :param pulumi.Input[_builtins.bool] interim_update_enabled: Enable periodic updates during active sessions. This allows tracking of ongoing session data like bandwidth usage.
        :param pulumi.Input[_builtins.int] interim_update_interval: The interval (in seconds) between interim updates when `interim_update_enabled` is true. Default is 3600 seconds (1 hour).
        :param pulumi.Input[_builtins.str] name: A friendly name for the RADIUS profile to help identify its purpose (e.g., 'Corporate Users' or 'Guest Access').
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the RADIUS profile should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] use_usg_acct_server: Use the controller as a RADIUS accounting server. This allows local accounting without an external RADIUS server.
        :param pulumi.Input[_builtins.bool] use_usg_auth_server: Use the controller as a RADIUS authentication server. This allows local authentication without an external RADIUS server.
        :param pulumi.Input[_builtins.bool] vlan_enabled: Enable VLAN assignment for wired clients based on RADIUS attributes. This allows network segmentation based on user authentication.
        :param pulumi.Input[_builtins.str] vlan_wlan_mode: VLAN assignment mode for wireless networks. Valid values are:
                 * `disabled` - Do not use RADIUS-assigned VLANs
                 * `optional` - Use RADIUS-assigned VLAN if provided
                 * `required` - Require RADIUS-assigned VLAN for authentication to succeed
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[RadiusProfileArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `RadiusProfile` resource manages RADIUS authentication profiles for UniFi networks.

        RADIUS (Remote Authentication Dial-In User Service) profiles enable enterprise-grade authentication and authorization for:
          * 802.1X network access control
          * WPA2/WPA3-Enterprise wireless networks
          * Dynamic VLAN assignment
          * User activity accounting

        Each profile can be configured with:
          * Multiple authentication and accounting servers
          * VLAN assignment settings
          * Accounting update intervals

        :param str resource_name: The name of the resource.
        :param RadiusProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RadiusProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accounting_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 acct_servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAcctServerArgs', 'RadiusProfileAcctServerArgsDict']]]]] = None,
                 auth_servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAuthServerArgs', 'RadiusProfileAuthServerArgsDict']]]]] = None,
                 interim_update_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 interim_update_interval: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 use_usg_acct_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_usg_auth_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 vlan_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 vlan_wlan_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RadiusProfileArgs.__new__(RadiusProfileArgs)

            __props__.__dict__["accounting_enabled"] = accounting_enabled
            __props__.__dict__["acct_servers"] = acct_servers
            __props__.__dict__["auth_servers"] = auth_servers
            __props__.__dict__["interim_update_enabled"] = interim_update_enabled
            __props__.__dict__["interim_update_interval"] = interim_update_interval
            __props__.__dict__["name"] = name
            __props__.__dict__["site"] = site
            __props__.__dict__["use_usg_acct_server"] = use_usg_acct_server
            __props__.__dict__["use_usg_auth_server"] = use_usg_auth_server
            __props__.__dict__["vlan_enabled"] = vlan_enabled
            __props__.__dict__["vlan_wlan_mode"] = vlan_wlan_mode
        super(RadiusProfile, __self__).__init__(
            'unifi:index/radiusProfile:RadiusProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accounting_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            acct_servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAcctServerArgs', 'RadiusProfileAcctServerArgsDict']]]]] = None,
            auth_servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAuthServerArgs', 'RadiusProfileAuthServerArgsDict']]]]] = None,
            interim_update_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            interim_update_interval: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None,
            use_usg_acct_server: Optional[pulumi.Input[_builtins.bool]] = None,
            use_usg_auth_server: Optional[pulumi.Input[_builtins.bool]] = None,
            vlan_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            vlan_wlan_mode: Optional[pulumi.Input[_builtins.str]] = None) -> 'RadiusProfile':
        """
        Get an existing RadiusProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] accounting_enabled: Enable RADIUS accounting to track user sessions, including login/logout times and data usage. Useful for billing and audit purposes.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAcctServerArgs', 'RadiusProfileAcctServerArgsDict']]]] acct_servers: List of RADIUS accounting servers to use with this profile. Accounting servers track session data like connection time and data usage. Each server requires:
                 * IP address of the RADIUS server
                 * Port number (default: 1813)
                 * Shared secret for secure communication
        :param pulumi.Input[Sequence[pulumi.Input[Union['RadiusProfileAuthServerArgs', 'RadiusProfileAuthServerArgsDict']]]] auth_servers: List of RADIUS authentication servers to use with this profile. Multiple servers provide failover - if the first server is unreachable, the system will try the next server in the list. Each server requires:
                 * IP address of the RADIUS server
                 * Shared secret for secure communication
        :param pulumi.Input[_builtins.bool] interim_update_enabled: Enable periodic updates during active sessions. This allows tracking of ongoing session data like bandwidth usage.
        :param pulumi.Input[_builtins.int] interim_update_interval: The interval (in seconds) between interim updates when `interim_update_enabled` is true. Default is 3600 seconds (1 hour).
        :param pulumi.Input[_builtins.str] name: A friendly name for the RADIUS profile to help identify its purpose (e.g., 'Corporate Users' or 'Guest Access').
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the RADIUS profile should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] use_usg_acct_server: Use the controller as a RADIUS accounting server. This allows local accounting without an external RADIUS server.
        :param pulumi.Input[_builtins.bool] use_usg_auth_server: Use the controller as a RADIUS authentication server. This allows local authentication without an external RADIUS server.
        :param pulumi.Input[_builtins.bool] vlan_enabled: Enable VLAN assignment for wired clients based on RADIUS attributes. This allows network segmentation based on user authentication.
        :param pulumi.Input[_builtins.str] vlan_wlan_mode: VLAN assignment mode for wireless networks. Valid values are:
                 * `disabled` - Do not use RADIUS-assigned VLANs
                 * `optional` - Use RADIUS-assigned VLAN if provided
                 * `required` - Require RADIUS-assigned VLAN for authentication to succeed
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RadiusProfileState.__new__(_RadiusProfileState)

        __props__.__dict__["accounting_enabled"] = accounting_enabled
        __props__.__dict__["acct_servers"] = acct_servers
        __props__.__dict__["auth_servers"] = auth_servers
        __props__.__dict__["interim_update_enabled"] = interim_update_enabled
        __props__.__dict__["interim_update_interval"] = interim_update_interval
        __props__.__dict__["name"] = name
        __props__.__dict__["site"] = site
        __props__.__dict__["use_usg_acct_server"] = use_usg_acct_server
        __props__.__dict__["use_usg_auth_server"] = use_usg_auth_server
        __props__.__dict__["vlan_enabled"] = vlan_enabled
        __props__.__dict__["vlan_wlan_mode"] = vlan_wlan_mode
        return RadiusProfile(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountingEnabled")
    def accounting_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable RADIUS accounting to track user sessions, including login/logout times and data usage. Useful for billing and audit purposes.
        """
        return pulumi.get(self, "accounting_enabled")

    @_builtins.property
    @pulumi.getter(name="acctServers")
    def acct_servers(self) -> pulumi.Output[Optional[Sequence['outputs.RadiusProfileAcctServer']]]:
        """
        List of RADIUS accounting servers to use with this profile. Accounting servers track session data like connection time and data usage. Each server requires:
          * IP address of the RADIUS server
          * Port number (default: 1813)
          * Shared secret for secure communication
        """
        return pulumi.get(self, "acct_servers")

    @_builtins.property
    @pulumi.getter(name="authServers")
    def auth_servers(self) -> pulumi.Output[Optional[Sequence['outputs.RadiusProfileAuthServer']]]:
        """
        List of RADIUS authentication servers to use with this profile. Multiple servers provide failover - if the first server is unreachable, the system will try the next server in the list. Each server requires:
          * IP address of the RADIUS server
          * Shared secret for secure communication
        """
        return pulumi.get(self, "auth_servers")

    @_builtins.property
    @pulumi.getter(name="interimUpdateEnabled")
    def interim_update_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable periodic updates during active sessions. This allows tracking of ongoing session data like bandwidth usage.
        """
        return pulumi.get(self, "interim_update_enabled")

    @_builtins.property
    @pulumi.getter(name="interimUpdateInterval")
    def interim_update_interval(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The interval (in seconds) between interim updates when `interim_update_enabled` is true. Default is 3600 seconds (1 hour).
        """
        return pulumi.get(self, "interim_update_interval")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A friendly name for the RADIUS profile to help identify its purpose (e.g., 'Corporate Users' or 'Guest Access').
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where the RADIUS profile should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter(name="useUsgAcctServer")
    def use_usg_acct_server(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Use the controller as a RADIUS accounting server. This allows local accounting without an external RADIUS server.
        """
        return pulumi.get(self, "use_usg_acct_server")

    @_builtins.property
    @pulumi.getter(name="useUsgAuthServer")
    def use_usg_auth_server(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Use the controller as a RADIUS authentication server. This allows local authentication without an external RADIUS server.
        """
        return pulumi.get(self, "use_usg_auth_server")

    @_builtins.property
    @pulumi.getter(name="vlanEnabled")
    def vlan_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable VLAN assignment for wired clients based on RADIUS attributes. This allows network segmentation based on user authentication.
        """
        return pulumi.get(self, "vlan_enabled")

    @_builtins.property
    @pulumi.getter(name="vlanWlanMode")
    def vlan_wlan_mode(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        VLAN assignment mode for wireless networks. Valid values are:
          * `disabled` - Do not use RADIUS-assigned VLANs
          * `optional` - Use RADIUS-assigned VLAN if provided
          * `required` - Require RADIUS-assigned VLAN for authentication to succeed
        """
        return pulumi.get(self, "vlan_wlan_mode")

